@@ -21,11 +21,6 @@ def DEBUG_MSG(msg):
 
     print(msg, file=sys.stderr, flush=True)
 
-def init_ray():
-    import ray
-    if not ray.is_initialized():
-        ray.init(ignore_reinit_error=True, object_store_memory=8000000000, num_cpus=8)
-
 
 def _get_ppm_tolerance(qualifiers):
     if qualifiers is None:
@@ -332,26 +327,10 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
     # Perfoming all the concrete queries
     collated_list = [] # This list holds the collated set of results from each query, final result is a concat of all of them
 
-    # Ray Parallel Version
     execute_serial = True
-    if parallel:
-        import ray
-        import msql_engine_ray
 
-        if ray.is_initialized():
-            # TODO: Divide up the parallel thing
-            chunk_size = 100
-            concrete_query_lists = [all_concrete_queries[i:i + chunk_size] for i in range(0, len(all_concrete_queries), chunk_size)]
-            futures = [msql_engine_ray._executeconditions_query_ray.remote(concrete_query_list, input_filename, ms1_input_df=ms1_df, ms2_input_df=ms2_df, cache=cache) for concrete_query_list in concrete_query_lists]
-            all_ray_results = ray.get(futures)
-
-            # Flattening this list of lists
-            collated_list = [item for sublist in all_ray_results for item in sublist]
-
-            execute_serial = False
-    
-    # This is the fallback
-    if execute_serial:
+    # We have no parallel path right now
+    if execute_serial or parallel:
         # Serial Version
         for concrete_query in tqdm(all_concrete_queries):
             results_ms1_df, results_ms2_df = _executeconditions_query(concrete_query, input_filename, ms1_input_df=ms1_df, ms2_input_df=ms2_df, cache=cache)
